@@ -4,5 +4,5 @@ MIN_PYTHON_MINOR = 7
 
 # Testing Defaults
 DEFAULT_LIVE_PORT = 8082
-DEFAULT_HIST_PORT = 8092
+DEFAULT_HIST_PORT = None
 DEFAULT_TEST_SYMBOL_LIST = ['BANKNIFTY-I', 'NIFTY-I', 'CRUDEOIL-I']
